@@ -22,6 +22,8 @@ import (
 
 	"github.com/distatus/battery"
 	process "github.com/shirou/gopsutil/v3/process"
+	"golang.org/x/text/cases"
+	"golang.org/x/text/language"
 )
 
 const (
@@ -31,6 +33,10 @@ const (
 	LinuxPlatform   = "linux"
 )
 
+var (
+	lock = sync.RWMutex{}
+)
+
 type Flags struct {
 	ErrorCode     int
 	Config        string
@@ -44,6 +50,7 @@ type Flags struct {
 	Migrate       bool
 	TerminalWidth int
 	Strict        bool
+	Debug         bool
 }
 
 type CommandError struct {
@@ -120,6 +127,22 @@ type TemplateCache struct {
 	Env          map[string]string
 	OS           string
 	WSL          bool
+	Segments     map[string]interface{}
+}
+
+func (t *TemplateCache) AddSegmentData(key string, value interface{}) {
+	lock.Lock()
+	defer lock.Unlock()
+	if t.Segments == nil {
+		t.Segments = make(map[string]interface{})
+	}
+	key = cases.Title(language.English).String(key)
+	t.Segments[key] = value
+}
+
+type BatteryInfo struct {
+	Percentage int
+	State      battery.State
 }
 
 type Environment interface {
@@ -149,7 +172,7 @@ type Environment interface {
 	RunShellCommand(shell, command string) string
 	ExecutionTime() float64
 	Flags() *Flags
-	BatteryInfo() ([]*battery.Battery, error)
+	BatteryState() (*BatteryInfo, error)
 	QueryWindowTitles(processName, windowTitleRegex string) (string, error)
 	WindowsRegistryKeyValue(path string) (*WindowsRegistryValue, error)
 	HTTPRequest(url string, timeout int, requestModifiers ...HTTPRequestModifier) ([]byte, error)
@@ -166,6 +189,7 @@ type Environment interface {
 	ConvertToWindowsPath(path string) string
 	WifiNetwork() (*WifiInfo, error)
 	TemplateCache() *TemplateCache
+	Trace(start time.Time, function string, args ...string)
 }
 
 type commandCache struct {
@@ -201,27 +225,26 @@ type ShellEnvironment struct {
 	fileCache  *fileCache
 	tmplCache  *TemplateCache
 	logBuilder strings.Builder
-	debug      bool
-	lock       sync.Mutex
 }
 
-func (env *ShellEnvironment) Init(debug bool) {
+func (env *ShellEnvironment) Init() {
+	defer env.Trace(time.Now(), "Init")
 	if env.CmdFlags == nil {
 		env.CmdFlags = &Flags{}
 	}
+	if env.CmdFlags.Debug {
+		log.SetOutput(&env.logBuilder)
+	}
 	env.fileCache = &fileCache{}
 	env.fileCache.Init(env.CachePath())
 	env.resolveConfigPath()
 	env.cmdCache = &commandCache{
 		commands: newConcurrentMap(),
 	}
-	if debug {
-		env.debug = true
-		log.SetOutput(&env.logBuilder)
-	}
 }
 
 func (env *ShellEnvironment) resolveConfigPath() {
+	defer env.Trace(time.Now(), "resolveConfigPath")
 	if len(env.CmdFlags.Config) == 0 {
 		env.CmdFlags.Config = env.Getenv("POSH_THEME")
 	}
@@ -229,12 +252,15 @@ func (env *ShellEnvironment) resolveConfigPath() {
 		env.CmdFlags.Config = fmt.Sprintf("https://raw.githubusercontent.com/JanDeDobbeleer/oh-my-posh/v%s/themes/default.omp.json", env.Version)
 	}
 	if strings.HasPrefix(env.CmdFlags.Config, "https://") {
-		env.getConfigPath(env.CmdFlags.Config)
-		return
+		if err := env.downloadConfig(env.CmdFlags.Config); err != nil {
+			// make it use default config when download fails
+			env.CmdFlags.Config = ""
+			return
+		}
 	}
 	// Cygwin path always needs the full path as we're on Windows but not really.
 	// Doing filepath actions will convert it to a Windows path and break the init script.
-	if env.Platform() == WindowsPlatform && env.Shell() == "constants.BASH" {
+	if env.Platform() == WindowsPlatform && env.Shell() == "bash" {
 		return
 	}
 	configFile := env.CmdFlags.Config
@@ -250,45 +276,28 @@ func (env *ShellEnvironment) resolveConfigPath() {
 	env.CmdFlags.Config = filepath.Clean(configFile)
 }
 
-func (env *ShellEnvironment) getConfigPath(location string) {
-	configFileName := fmt.Sprintf("%s.omp.json", env.Version)
-	configPath := filepath.Join(env.CachePath(), configFileName)
-	if env.HasFilesInDir(env.CachePath(), configFileName) {
-		env.CmdFlags.Config = configPath
-		return
-	}
-	// clean old config files
-	cleanCacheDir := func() {
-		dir, err := ioutil.ReadDir(env.CachePath())
-		if err != nil {
-			return
-		}
-		for _, file := range dir {
-			if strings.HasSuffix(file.Name(), ".omp.json") {
-				os.Remove(filepath.Join(env.CachePath(), file.Name()))
-			}
-		}
-	}
-	cleanCacheDir()
-
+func (env *ShellEnvironment) downloadConfig(location string) error {
+	defer env.Trace(time.Now(), "downloadConfig", location)
+	configPath := filepath.Join(env.CachePath(), "config.omp.json")
 	cfg, err := env.HTTPRequest(location, 5000)
 	if err != nil {
-		return
+		return err
 	}
 	out, err := os.Create(configPath)
 	if err != nil {
-		return
+		return err
 	}
 	defer out.Close()
 	_, err = io.Copy(out, bytes.NewReader(cfg))
 	if err != nil {
-		return
+		return err
 	}
 	env.CmdFlags.Config = configPath
+	return nil
 }
 
-func (env *ShellEnvironment) trace(start time.Time, function string, args ...string) {
-	if !env.debug {
+func (env *ShellEnvironment) Trace(start time.Time, function string, args ...string) {
+	if env.CmdFlags == nil || !env.CmdFlags.Debug {
 		return
 	}
 	elapsed := time.Since(start)
@@ -297,7 +306,7 @@ func (env *ShellEnvironment) trace(start time.Time, function string, args ...str
 }
 
 func (env *ShellEnvironment) log(lt logType, function, message string) {
-	if !env.debug {
+	if !env.CmdFlags.Debug {
 		return
 	}
 	trace := fmt.Sprintf("%s: %s\n%s", lt, function, message)
@@ -305,7 +314,7 @@ func (env *ShellEnvironment) log(lt logType, function, message string) {
 }
 
 func (env *ShellEnvironment) debugF(function string, fn func() string) {
-	if !env.debug {
+	if !env.CmdFlags.Debug {
 		return
 	}
 	trace := fmt.Sprintf("%s: %s\n%s", Debug, function, fn())
@@ -313,17 +322,17 @@ func (env *ShellEnvironment) debugF(function string, fn func() string) {
 }
 
 func (env *ShellEnvironment) Getenv(key string) string {
-	defer env.trace(time.Now(), "Getenv", key)
+	defer env.Trace(time.Now(), "Getenv", key)
 	val := os.Getenv(key)
 	env.log(Debug, "Getenv", val)
 	return val
 }
 
 func (env *ShellEnvironment) Pwd() string {
-	defer env.trace(time.Now(), "Pwd")
-	env.lock.Lock()
+	defer env.Trace(time.Now(), "Pwd")
+	lock.Lock()
 	defer func() {
-		env.lock.Unlock()
+		lock.Unlock()
 		env.log(Debug, "Pwd", env.cwd)
 	}()
 	if env.cwd != "" {
@@ -348,7 +357,7 @@ func (env *ShellEnvironment) Pwd() string {
 }
 
 func (env *ShellEnvironment) HasFiles(pattern string) bool {
-	defer env.trace(time.Now(), "HasFiles", pattern)
+	defer env.Trace(time.Now(), "HasFiles", pattern)
 	cwd := env.Pwd()
 	pattern = cwd + env.PathSeparator() + pattern
 	matches, err := filepath.Glob(pattern)
@@ -356,13 +365,20 @@ func (env *ShellEnvironment) HasFiles(pattern string) bool {
 		env.log(Error, "HasFiles", err.Error())
 		return false
 	}
-	hasFiles := len(matches) > 0
-	env.debugF("HasFiles", func() string { return strconv.FormatBool(hasFiles) })
-	return hasFiles
+	for _, match := range matches {
+		f, _ := os.Stat(match)
+		if f.IsDir() {
+			continue
+		}
+		env.log(Debug, "HasFiles", "true")
+		return true
+	}
+	env.log(Debug, "HasFiles", "false")
+	return false
 }
 
 func (env *ShellEnvironment) HasFilesInDir(dir, pattern string) bool {
-	defer env.trace(time.Now(), "HasFilesInDir", pattern)
+	defer env.Trace(time.Now(), "HasFilesInDir", pattern)
 	pattern = dir + env.PathSeparator() + pattern
 	matches, err := filepath.Glob(pattern)
 	if err != nil {
@@ -375,7 +391,7 @@ func (env *ShellEnvironment) HasFilesInDir(dir, pattern string) bool {
 }
 
 func (env *ShellEnvironment) HasFileInParentDirs(pattern string, depth uint) bool {
-	defer env.trace(time.Now(), "HasFileInParent", pattern, fmt.Sprint(depth))
+	defer env.Trace(time.Now(), "HasFileInParent", pattern, fmt.Sprint(depth))
 	currentFolder := env.Pwd()
 
 	for c := 0; c < int(depth); c++ {
@@ -396,11 +412,14 @@ func (env *ShellEnvironment) HasFileInParentDirs(pattern string, depth uint) boo
 }
 
 func (env *ShellEnvironment) HasFolder(folder string) bool {
-	defer env.trace(time.Now(), "HasFolder", folder)
-	_, err := os.Stat(folder)
-	hasFolder := !os.IsNotExist(err)
-	env.debugF("HasFolder", func() string { return strconv.FormatBool(hasFolder) })
-	return hasFolder
+	defer env.Trace(time.Now(), "HasFolder", folder)
+	f, err := os.Stat(folder)
+	if err != nil {
+		env.log(Debug, "HasFolder", "false")
+		return false
+	}
+	env.debugF("HasFolder", func() string { return strconv.FormatBool(f.IsDir()) })
+	return f.IsDir()
 }
 
 func (env *ShellEnvironment) ResolveSymlink(path string) (string, error) {
@@ -408,7 +427,7 @@ func (env *ShellEnvironment) ResolveSymlink(path string) (string, error) {
 }
 
 func (env *ShellEnvironment) FileContent(file string) string {
-	defer env.trace(time.Now(), "FileContent", file)
+	defer env.Trace(time.Now(), "FileContent", file)
 	if !filepath.IsAbs(file) {
 		file = filepath.Join(env.Pwd(), file)
 	}
@@ -423,7 +442,7 @@ func (env *ShellEnvironment) FileContent(file string) string {
 }
 
 func (env *ShellEnvironment) LsDir(path string) []fs.DirEntry {
-	defer env.trace(time.Now(), "LsDir", path)
+	defer env.Trace(time.Now(), "LsDir", path)
 	entries, err := os.ReadDir(path)
 	if err != nil {
 		env.log(Error, "LsDir", err.Error())
@@ -440,12 +459,12 @@ func (env *ShellEnvironment) LsDir(path string) []fs.DirEntry {
 }
 
 func (env *ShellEnvironment) PathSeparator() string {
-	defer env.trace(time.Now(), "PathSeparator")
+	defer env.Trace(time.Now(), "PathSeparator")
 	return string(os.PathSeparator)
 }
 
 func (env *ShellEnvironment) User() string {
-	defer env.trace(time.Now(), "User")
+	defer env.Trace(time.Now(), "User")
 	user := os.Getenv("USER")
 	if user == "" {
 		user = os.Getenv("USERNAME")
@@ -455,7 +474,7 @@ func (env *ShellEnvironment) User() string {
 }
 
 func (env *ShellEnvironment) Host() (string, error) {
-	defer env.trace(time.Now(), "Host")
+	defer env.Trace(time.Now(), "Host")
 	hostName, err := os.Hostname()
 	if err != nil {
 		env.log(Error, "Host", err.Error())
@@ -467,12 +486,12 @@ func (env *ShellEnvironment) Host() (string, error) {
 }
 
 func (env *ShellEnvironment) GOOS() string {
-	defer env.trace(time.Now(), "GOOS")
+	defer env.Trace(time.Now(), "GOOS")
 	return runtime.GOOS
 }
 
 func (env *ShellEnvironment) RunCommand(command string, args ...string) (string, error) {
-	defer env.trace(time.Now(), "RunCommand", append([]string{command}, args...)...)
+	defer env.Trace(time.Now(), "RunCommand", append([]string{command}, args...)...)
 	if cmd, ok := env.cmdCache.get(command); ok {
 		command = cmd
 	}
@@ -499,7 +518,7 @@ func (env *ShellEnvironment) RunCommand(command string, args ...string) (string,
 }
 
 func (env *ShellEnvironment) RunShellCommand(shell, command string) string {
-	defer env.trace(time.Now(), "RunShellCommand", shell, command)
+	defer env.Trace(time.Now(), "RunShellCommand", shell, command)
 	if out, err := env.RunCommand(shell, "-c", command); err == nil {
 		return out
 	}
@@ -507,7 +526,7 @@ func (env *ShellEnvironment) RunShellCommand(shell, command string) string {
 }
 
 func (env *ShellEnvironment) CommandPath(command string) string {
-	defer env.trace(time.Now(), "HasCommand", command)
+	defer env.Trace(time.Now(), "HasCommand", command)
 	if path, ok := env.cmdCache.get(command); ok {
 		return path
 	}
@@ -533,12 +552,12 @@ func (env *ShellEnvironment) HasCommand(command string) bool {
 }
 
 func (env *ShellEnvironment) ErrorCode() int {
-	defer env.trace(time.Now(), "ErrorCode")
+	defer env.Trace(time.Now(), "ErrorCode")
 	return env.CmdFlags.ErrorCode
 }
 
 func (env *ShellEnvironment) ExecutionTime() float64 {
-	defer env.trace(time.Now(), "ExecutionTime")
+	defer env.Trace(time.Now(), "ExecutionTime")
 	if env.CmdFlags.ExecutionTime < 0 {
 		return 0
 	}
@@ -546,72 +565,12 @@ func (env *ShellEnvironment) ExecutionTime() float64 {
 }
 
 func (env *ShellEnvironment) Flags() *Flags {
-	defer env.trace(time.Now(), "Flags")
+	defer env.Trace(time.Now(), "Flags")
 	return env.CmdFlags
 }
 
-func (env *ShellEnvironment) BatteryInfo() ([]*battery.Battery, error) {
-	defer env.trace(time.Now(), "BatteryInfo")
-	batteries, err := battery.GetAll()
-	// actual error, return it
-	if err != nil && len(batteries) == 0 {
-		env.log(Error, "BatteryInfo", err.Error())
-		return nil, err
-	}
-	// there are no batteries found
-	if len(batteries) == 0 {
-		return nil, &NoBatteryError{}
-	}
-	// some batteries fail to get retrieved, filter them out if present
-	validBatteries := []*battery.Battery{}
-	for _, batt := range batteries {
-		if batt != nil {
-			validBatteries = append(validBatteries, batt)
-		}
-	}
-	// clean minor errors
-	unableToRetrieveBatteryInfo := "A device which does not exist was specified."
-	unknownChargeRate := "Unknown value received"
-	var fatalErr battery.Errors
-	ignoreErr := func(err error) bool {
-		if e, ok := err.(battery.ErrPartial); ok {
-			// ignore unknown charge rate value error
-			if e.Current == nil &&
-				e.Design == nil &&
-				e.DesignVoltage == nil &&
-				e.Full == nil &&
-				e.State == nil &&
-				e.Voltage == nil &&
-				e.ChargeRate != nil &&
-				e.ChargeRate.Error() == unknownChargeRate {
-				return true
-			}
-		}
-		return false
-	}
-	if batErr, ok := err.(battery.Errors); ok {
-		for _, err := range batErr {
-			if !ignoreErr(err) {
-				fatalErr = append(fatalErr, err)
-			}
-		}
-	}
-
-	// when battery info fails to get retrieved but there is at least one valid battery, return it without error
-	if len(validBatteries) > 0 && fatalErr != nil && strings.Contains(fatalErr.Error(), unableToRetrieveBatteryInfo) {
-		return validBatteries, nil
-	}
-	// another error occurred (possibly unmapped use-case), return it
-	if fatalErr != nil {
-		env.log(Error, "BatteryInfo", fatalErr.Error())
-		return nil, fatalErr
-	}
-	// everything is fine
-	return validBatteries, nil
-}
-
 func (env *ShellEnvironment) Shell() string {
-	defer env.trace(time.Now(), "Shell")
+	defer env.Trace(time.Now(), "Shell")
 	if env.CmdFlags.Shell != "" {
 		return env.CmdFlags.Shell
 	}
@@ -631,12 +590,12 @@ func (env *ShellEnvironment) Shell() string {
 		return Unknown
 	}
 	// Cache the shell value to speed things up.
-	env.CmdFlags.Shell = strings.Trim(strings.Replace(name, ".exe", "", 1), " ")
+	env.CmdFlags.Shell = strings.Trim(strings.TrimSuffix(name, ".exe"), " ")
 	return env.CmdFlags.Shell
 }
 
 func (env *ShellEnvironment) HTTPRequest(targetURL string, timeout int, requestModifiers ...HTTPRequestModifier) ([]byte, error) {
-	defer env.trace(time.Now(), "HTTPRequest", targetURL)
+	defer env.Trace(time.Now(), "HTTPRequest", targetURL)
 	ctx, cncl := context.WithTimeout(context.Background(), time.Millisecond*time.Duration(timeout))
 	defer cncl()
 	request, err := http.NewRequestWithContext(ctx, http.MethodGet, targetURL, nil)
@@ -651,6 +610,13 @@ func (env *ShellEnvironment) HTTPRequest(targetURL string, timeout int, requestM
 		env.log(Error, "HTTPRequest", err.Error())
 		return nil, err
 	}
+	// anything inside the range [200, 299] is considered a success
+	if response.StatusCode < 200 || response.StatusCode >= 300 {
+		message := "HTTP status code " + strconv.Itoa(response.StatusCode)
+		err := errors.New(message)
+		env.log(Error, "HTTPRequest", message)
+		return nil, err
+	}
 	defer response.Body.Close()
 	body, err := ioutil.ReadAll(response.Body)
 	if err != nil {
@@ -662,7 +628,7 @@ func (env *ShellEnvironment) HTTPRequest(targetURL string, timeout int, requestM
 }
 
 func (env *ShellEnvironment) HasParentFilePath(path string) (*FileInfo, error) {
-	defer env.trace(time.Now(), "HasParentFilePath", path)
+	defer env.Trace(time.Now(), "HasParentFilePath", path)
 	currentFolder := env.Pwd()
 	for {
 		searchPath := filepath.Join(currentFolder, path)
@@ -687,7 +653,7 @@ func (env *ShellEnvironment) HasParentFilePath(path string) (*FileInfo, error) {
 }
 
 func (env *ShellEnvironment) StackCount() int {
-	defer env.trace(time.Now(), "StackCount")
+	defer env.Trace(time.Now(), "StackCount")
 	if env.CmdFlags.StackCount < 0 {
 		return 0
 	}
@@ -707,7 +673,7 @@ func (env *ShellEnvironment) Logs() string {
 }
 
 func (env *ShellEnvironment) TemplateCache() *TemplateCache {
-	defer env.trace(time.Now(), "TemplateCache")
+	defer env.Trace(time.Now(), "TemplateCache")
 	if env.tmplCache != nil {
 		return env.tmplCache
 	}
@@ -747,8 +713,21 @@ func (env *ShellEnvironment) TemplateCache() *TemplateCache {
 	return tmplCache
 }
 
-func (env *ShellEnvironment) DirMatchesOneOf(dir string, regexes []string) bool {
-	return dirMatchesOneOf(dir, env.Home(), env.GOOS(), regexes)
+func (env *ShellEnvironment) DirMatchesOneOf(dir string, regexes []string) (match bool) {
+	lock.Lock()
+	defer lock.Unlock()
+	// sometimes the function panics inside golang, we want to silence that error
+	// and assume that there's no match. Not perfect, but better than crashing
+	// for the time being until we figure out what the actual root cause is
+	defer func() {
+		if err := recover(); err != nil {
+			message := fmt.Sprintf("%s", err)
+			env.log(Error, "DirMatchesOneOf", message)
+			match = false
+		}
+	}()
+	match = dirMatchesOneOf(dir, env.Home(), env.GOOS(), regexes)
+	return
 }
 
 func dirMatchesOneOf(dir, home, goos string, regexes []string) bool {
